@@ -6,7 +6,10 @@
 
 package Tcl::pTk::After;
 
-our ($VERSION) = ('1.04_03');
+our ($VERSION) = ('1.06_01');
+
+use warnings;
+use strict;
 
 use Carp;
 
