@@ -4,7 +4,10 @@
 
 package Tcl::pTk::LabEntry;
 
-our ($VERSION) = ('1.04_03');
+our ($VERSION) = ('1.06_01');
+
+use warnings;
+use strict;
 
 use base  qw(Tcl::pTk::Frame);
 #use Tk::widgets qw(Frame Label Entry);
