@@ -1,6 +1,9 @@
 package Tcl::pTk::MainWindow;
 
-our ($VERSION) = ('1.04_03');
+our ($VERSION) = ('1.06_01');
+
+use warnings;
+use strict;
 
 use Tcl::pTk::Toplevel;
 
